@@ -4,7 +4,7 @@
 
 use std::{fs, io};
 use std::collections::HashSet;
-use std::path::{Path, PathBuf};
+use std::path::Path;
 use bytes::Bytes;
 use log::error;
 use rpki::repository::tal::TalUri;
@@ -30,9 +30,6 @@ use super::{rrdp, rsync};
 /// you need to call [`ignite`][Self::ignite] once.
 #[derive(Debug)]
 pub struct Collector {
-    /// The base directory of the cache.
-    cache_dir: PathBuf,
-
     /// The collector for RRDP transport.
     ///
     /// If this is `None`, use of RRDP has been disabled entirely.
@@ -47,7 +44,8 @@ pub struct Collector {
 impl Collector {
     /// Initializes the collector without creating a value.
     ///
-    /// Ensures that the base directory exists and creates it if necessary.
+    /// Ensures that the base directory exists. This will _not_ create the
+    /// base directory to ensure that `routinator init` has been run.
     ///
     /// The function is called implicitly by [`new`][Self::new].
     pub fn init(config: &Config) -> Result<(), Failed> {
@@ -68,6 +66,7 @@ impl Collector {
             }
             return Err(Failed)
         }
+        rrdp::Collector::init(config)?;
         rsync::Collector::init(config)?;
         Ok(())
     }
@@ -77,12 +76,10 @@ impl Collector {
     /// Takes all necessary information from `config`.
     pub fn new(
         config: &Config,
-        db: &sled::Db,
     ) -> Result<Self, Failed> {
         Self::init(config)?;
         Ok(Collector {
-            cache_dir: config.cache_dir.clone(),
-            rrdp: rrdp::Collector::new(config, db)?,
+            rrdp: rrdp::Collector::new(config)?,
             rsync: rsync::Collector::new(config)?,
         })
     }
@@ -102,14 +99,6 @@ impl Collector {
         Run::new(self)
     }
 
-    /// Prepares for a cleanup run.
-    ///
-    /// The method returns a [`Cleanup`] value that can be used to register
-    /// those repositories that should be kept around.
-    pub fn cleanup(&self) -> Cleanup {
-        Cleanup::new(self)
-    }
-
     /// Dumps the content of the collector and store owned by the engine.
     pub fn dump(&self, dir: &Path) -> Result<(), Failed> {
         if let Some(rrdp) = self.rrdp.as_ref() {
@@ -133,12 +122,9 @@ impl Collector {
 ///
 /// This type references the underlying [`Collector`]. It can be used with
 /// multiple threads using
-/// [crossbeam’s][https://github.com/crossbeam-rs/crossbeam] scoped threads.
+/// [crossbeam’s](https://github.com/crossbeam-rs/crossbeam) scoped threads.
 #[derive(Debug)]
 pub struct Run<'a> {
-    /// A reference to the underlying collector.
-    collector: &'a Collector,
-
     /// The runner for rsync if this transport is enabled.
     rsync: Option<rsync::Run<'a>>,
 
@@ -150,7 +136,6 @@ impl<'a> Run<'a> {
     /// Creates a new validation run for the given collector.
     fn new(collector: &'a Collector) -> Self {
         Run {
-            collector,
             rsync: collector.rsync.as_ref().map(|rsync| rsync.start()),
             rrdp: collector.rrdp.as_ref().map(|rrdp| rrdp.start()),
         }
@@ -234,6 +219,20 @@ impl<'a> Run<'a> {
         }
         true
     }
+
+    /// Cleans the collector.
+    ///
+    /// Any RRDP repository or rsync module not included in `retain` will
+    /// be deleted.
+    pub fn cleanup(&self, retain: &mut Cleanup) -> Result<(), Failed> {
+        if let Some(rsync) = self.rsync.as_ref() {
+            rsync.cleanup(&mut retain.rsync)?;
+        }
+        if let Some(rrdp) = self.rrdp.as_ref() {
+            rrdp.cleanup(&mut retain.rrdp)?;
+        }
+        Ok(())
+    }
 }
 
 
@@ -285,7 +284,7 @@ impl<'a> Repository<'a> {
     ) -> Result<Option<Bytes>, Failed> {
         match self.0 {
             RepoInner::Rrdp { ref repository } => {
-                repository.load_file(uri)
+                repository.load_object(uri)
             }
             RepoInner::Rsync { rsync } => {
                 Ok(rsync.load_file(uri))
@@ -297,19 +296,9 @@ impl<'a> Repository<'a> {
 
 //------------ Cleanup -------------------------------------------------------
 
-/// A builder-style type for cleanup.
-///
-/// This type can be requested from a collector via [`Collector::cleanup`]. 
-/// Repositories that should be be kept in the collector can be registered via
-/// the [`retain_rrdp_repository`][Cleanup::retain_rrdp_repository] and
-/// [`retain_rsync_module`][Cleanup::retain_rsync_module] methods. A call to
-/// [`commit`][Cleanup::commit] will cause the collector to delete all
-/// repositories that have not been registered.
-#[derive(Clone, Debug)]
-pub struct Cleanup<'a> {
-    /// A reference to the underlying collector.
-    collector: &'a Collector,
-
+/// A builder-style type for data retained during cleanup.
+#[derive(Clone, Debug, Default)]
+pub struct Cleanup {
     /// The set of rsync modules to retain.
     rsync: rsync::ModuleSet,
 
@@ -317,39 +306,20 @@ pub struct Cleanup<'a> {
     rrdp: HashSet<uri::Https>,
 }
 
-impl<'a> Cleanup<'a> {
+impl Cleanup {
     /// Creates a new cleanup object for the given collector.
-    fn new(collector: &'a Collector) -> Self {
-        Cleanup {
-            collector,
-            rsync: Default::default(),
-            rrdp: Default::default(),
-        }
+    pub fn new() -> Self {
+        Default::default()
     }
 
     /// Registers an RRDP repository to be retained in cleanup.
-    pub fn retain_rrdp_repository(&mut self, rpki_notify: &uri::Https) {
-        if self.collector.rrdp.is_some() {
-            self.rrdp.insert(rpki_notify.clone());
-        }
+    pub fn add_rrdp_repository(&mut self, rpki_notify: &uri::Https) {
+        self.rrdp.insert(rpki_notify.clone());
     }
 
     /// Registers an rsync module to be retained in cleanup.
-    pub fn retain_rsync_module(&mut self, uri: &uri::Rsync) {
-        if self.collector.rsync.is_some() {
-            self.rsync.add_from_uri(uri);
-        }
-    }
-
-    /// Performs the cleanup run.
-    pub fn commit(self) -> Result<(), Failed> {
-        if let Some(rsync) = self.collector.rsync.as_ref() {
-            rsync.cleanup(&self.rsync)
-        }
-        if let Some(rrdp) = self.collector.rrdp.as_ref() {
-            rrdp.cleanup(&self.rrdp)?
-        }
-        Ok(())
+    pub fn add_rsync_module(&mut self, uri: &uri::Rsync) {
+        self.rsync.add_from_uri(uri);
     }
 }
 
