@@ -153,6 +153,7 @@ impl Store {
 
     /// Dumps the content of the store.
     pub fn dump(&self, dir: &Path) -> Result<(), Failed> {
+        self.dump_ta_certs(dir)?;
         let dir = dir.join("store");
         debug!("Dumping store content to {}", dir.display());
         fatal::remove_dir_all(&dir)?;
@@ -164,6 +165,20 @@ impl Store {
         Ok(())
     }
 
+    /// Dumps all the stored trust anchor certificates.
+    fn dump_ta_certs(
+        &self,
+        target_base: &Path
+    ) -> Result<(), Failed> {
+        let source = self.path.join("ta");
+        let target = target_base.join("ta");
+        debug!("Dumping trust anchor certificates to {}", target.display());
+        fatal::remove_dir_all(&target)?;
+        fatal::copy_dir_all(&source, &target)?;
+        debug!("Trust anchor certificate dump complete.");
+        Ok(())
+    }
+
     /// Dumps all the stored points found in the tree under `path`.
     ///
     /// The point’s repository and rsync URI is determined from the stored
@@ -1188,7 +1203,7 @@ mod test {
     #[test]
     fn write_read_stored_manifest() {
         let mut orig = StoredManifest::new(
-            Time::utc(2021, 02, 18, 13, 22, 06),
+            Time::utc(2021, 2, 18, 13, 22, 6),
             Some(uri::Https::from_str("https://foo.bar/bla/blubb").unwrap()),
             uri::Rsync::from_str("rsync://foo.bar/bla/blubb").unwrap(),
             uri::Rsync::from_str("rsync://foo.bar/bla/blubb").unwrap(),
